==> knative-model-5.0.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/prometheus/v1alpha1/PrometheusSourceListFluent.java <==
package io.fabric8.knative.eventing.contrib.prometheus.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PrometheusSourceListFluent<A extends PrometheusSourceListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,PrometheusSource item);
    public A setToItems(int index,PrometheusSource item);
    public A addToItems(PrometheusSource... items);
    public A addAllToItems(Collection<PrometheusSource> items);
    public A removeFromItems(PrometheusSource... items);
    public A removeAllFromItems(Collection<PrometheusSource> items);
    public A removeMatchingFromItems(Predicate<PrometheusSourceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PrometheusSource> getItems();
    public List<PrometheusSource> buildItems();
    public PrometheusSource buildItem(int index);
    public PrometheusSource buildFirstItem();
    public PrometheusSource buildLastItem();
    public PrometheusSource buildMatchingItem(Predicate<PrometheusSourceBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<PrometheusSourceBuilder> predicate);
    public A withItems(List<PrometheusSource> items);
    public A withItems(PrometheusSource... items);
    public Boolean hasItems();
    public PrometheusSourceListFluent.ItemsNested<A> addNewItem();
    public PrometheusSourceListFluent.ItemsNested<A> addNewItemLike(PrometheusSource item);
    public PrometheusSourceListFluent.ItemsNested<A> setNewItemLike(int index,PrometheusSource item);
    public PrometheusSourceListFluent.ItemsNested<A> editItem(int index);
    public PrometheusSourceListFluent.ItemsNested<A> editFirstItem();
    public PrometheusSourceListFluent.ItemsNested<A> editLastItem();
    public PrometheusSourceListFluent.ItemsNested<A> editMatchingItem(Predicate<PrometheusSourceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PrometheusSourceFluent<PrometheusSourceListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/prometheus/v1alpha1/PrometheusSourceListFluent.java <==
package io.fabric8.knative.eventing.contrib.prometheus.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PrometheusSourceListFluent<A extends PrometheusSourceListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,PrometheusSource item);
    public A setToItems(int index,PrometheusSource item);
    public A addToItems(PrometheusSource... items);
    public A addAllToItems(Collection<PrometheusSource> items);
    public A removeFromItems(PrometheusSource... items);
    public A removeAllFromItems(Collection<PrometheusSource> items);
    public A removeMatchingFromItems(Predicate<PrometheusSourceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PrometheusSource> getItems();
    public List<PrometheusSource> buildItems();
    public PrometheusSource buildItem(int index);
    public PrometheusSource buildFirstItem();
    public PrometheusSource buildLastItem();
    public PrometheusSource buildMatchingItem(Predicate<PrometheusSourceBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<PrometheusSourceBuilder> predicate);
    public A withItems(List<PrometheusSource> items);
    public A withItems(PrometheusSource... items);
    public Boolean hasItems();
    public PrometheusSourceListFluent.ItemsNested<A> addNewItem();
    public PrometheusSourceListFluent.ItemsNested<A> addNewItemLike(PrometheusSource item);
    public PrometheusSourceListFluent.ItemsNested<A> setNewItemLike(int index,PrometheusSource item);
    public PrometheusSourceListFluent.ItemsNested<A> editItem(int index);
    public PrometheusSourceListFluent.ItemsNested<A> editFirstItem();
    public PrometheusSourceListFluent.ItemsNested<A> editLastItem();
    public PrometheusSourceListFluent.ItemsNested<A> editMatchingItem(Predicate<PrometheusSourceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PrometheusSourceFluent<PrometheusSourceListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
